==> terminus-client-python-0.0.15.tar.gz: terminus-client-python-0.0.15/README.md <==
Terminus Client Python
==========================

[![build status](https://api.travis-ci.org/terminusdb/terminus-client-python.svg?branch=master)](https://travis-ci.org/terminusdb/terminus-client-python)
[![Documentation Status](https://readthedocs.org/projects/terminus-client-python/badge/?version=latest)](https://terminus-client-python.readthedocs.io/en/latest/?badge=latest)

Python terminus client for TerminusDB API and WOQLpy

## Requirements
- [TerminusDB](https://github.com/terminusdb/terminus-server)
- [Python >= 3.6]

## Installation
-  Terminus Client Python can be download form PyPI using pip:
`pip3 install terminus-client-python`

- Or you can choose to install from this repo:
`pip3 install git+https://github.com/terminusdb/terminus-client-python.git`

## Usage
For the [full Documentation](https://terminus-client-python.readthedocs.io/)

## Tutorials
Visit [terminus-tutorials](https://github.com/terminusdb/terminus-tutorials) for tutorial scripts

## Testing
* Clone this repository
`git clone https://github.com/terminusdb/terminus-client-python.git`

* Install all development dependencies and run tests
```sh
$ make
```

* To run tests only
```sh
$ pytest tests
```

## Report Issues

If you have encounter any issues, please report it with your os and environment setup, version that you are using and a simple reproducible case.

If you encounter other questions, you can ask in our community [forum](https://community.terminusdb.com/) or [Slack channel](http://bit.ly/terminusdb-slack).

## Contribute

It will be nice, if you open an issue first so that we can know what is going on, then, fork this repo and push in your ideas. Do not forget to add a bit of test(s) of what value you adding.

Please check [Contributing.md](Contributing.md) for more information.

## Licence

GNU General Public License v3 (GPLv3)

Copyright (c) 2019

==> terminus-client-python-0.0.19.tar.gz: terminus-client-python-0.0.19/README.md <==
Terminus Client Python
==========================

[![build status](https://api.travis-ci.com/terminusdb/terminus-client-python.svg?branch=master)](https://travis-ci.com/terminusdb/terminus-client-python)
[![Documentation Status](https://readthedocs.org/projects/terminus-client-python/badge/?version=latest)](https://terminus-client-python.readthedocs.io/en/latest/?badge=latest)

Python terminus client for TerminusDB API and WOQLpy

## Requirements
- [TerminusDB](https://github.com/terminusdb/terminus-server)
- [Python >= 3.6]

## Installation
-  Terminus Client Python can be download form PyPI using pip:
`python -m pip install terminus-client-python`

this only include the core Python Client and WOQLQuery.

If you want to use woqlDataframe:

`python -m pip install terminus-client-python[dataframe]`

*if you are installing form `zsh` you have to quote the argument like this:*

`python -m pip install 'terminus-client-python[dataframe]'`

- Install from source:

`python -m pip install git+https://github.com/terminusdb/terminus-client-python.git`

## Usage
For the [full Documentation](https://terminus-client-python.readthedocs.io/)

## Tutorials
Visit [terminus-tutorials](https://github.com/terminusdb/terminus-tutorials) for tutorial scripts

## Testing
* Clone this repository
`git clone https://github.com/terminusdb/terminus-client-python.git`

* Install all development dependencies and run tests
```sh
$ make
```

* To run tests only
```sh
$ pytest tests
```

## Report Issues

If you have encounter any issues, please report it with your os and environment setup, version that you are using and a simple reproducible case.

If you encounter other questions, you can ask in our community [forum](https://community.terminusdb.com/) or [Slack channel](http://bit.ly/terminusdb-slack).

## Contribute

It will be nice, if you open an issue first so that we can know what is going on, then, fork this repo and push in your ideas. Do not forget to add a bit of test(s) of what value you adding.

Please check [Contributing.md](Contributing.md) for more information.

## Licence

GNU General Public License v3 (GPLv3)

Copyright (c) 2019
